@@ -9,7 +9,7 @@ from fundquant.main_interface.monitor import IndexMonitor
 def do_job(n_days=7):
     try:
         JslEtf().persist_all_data()
-        persist_monitor_data_hand()
+        # persist_monitor_data_hand()
         IndexMonitor().monitor()
     except Exception as e:
         email_list = SendEmail.get_email_list()
@@ -24,4 +24,4 @@ def persist_lxr_data_hand(cookie):
 
 
 if __name__ == '__main__':
-    do_job(15)
+    do_job(7)
