@@ -14,7 +14,7 @@ class EtfStatistic:
         self.etf_name = etf_tack.etf_name
         self.index_code = etf_tack.index_code
         self.index_name = etf_tack.index_name
-        self.strategy = etf_tack.strategy
+        self.is_pe = etf_tack.is_pe
         self.track_days = etf_tack.track_days
 
         # pe统计 最近10年
